/**
 * This file includes functions for interacting with an ADC
 *
 * Written for: TI ADS8698 8-channel ADC
 *
 * Connections:
 *    Function | ADC Pin     | AVR Port   | Pin # on DIP Atmega328P
 *   ----------+-------------+------------+-------------------------
 *    Data In  |  1 (SDI)    | PB3 (MOSI) | 17
 *    Reset    |  2 (RST)    | PC0        | 23
 *    Data Out | 36 (SDO)    | PB4 (MISO) | 18
 *    Clock    | 37 (SCLK)   | PB5 (SCK)  | 19
 *    Chip Sel.| 38 (CS)     | PC1        | 24
 */


/* ADC Commands.
 *
 * See datasheet section 8.5.1.
 */
typedef enum {
    ADS8698_NO_OP       = 0x00,  // Continue operating in previous mode.
    ADS8698_STANDBY     = 0x82,  // Enter standby mode.
    ADS8698_POWER_DOWN  = 0x83,  // Power down.
    ADS8698_RESET       = 0x85,  // Reset.
    ADS8698_AUTO_RESET  = 0xA0,  // Reset and enter auto-scan mode.
    ADS8698_MANUAL_CH0  = 0xC0,  // Select channel 0 input.
    ADS8698_MANUAL_CH1  = 0xC4,  // Select channel 1 input.
    ADS8698_MANUAL_CH2  = 0xC8,  // Select channel 2 input.
    ADS8698_MANUAL_CH3  = 0xCC,  // Select channel 3 input.
    ADS8698_MANUAL_CH4  = 0xD0,  // Select channel 4 input.
    ADS8698_MANUAL_CH5  = 0xD4,  // Select channel 5 input.
    ADS8698_MANUAL_CH6  = 0xD8,  // Select channel 6 input.
    ADS8698_MANUAL_CH7  = 0xDC,  // Select channel 7 input.
    ADS8698_MANUAL_AUX  = 0xE0,  // Select aux input.
} ADS8698_command;


/* ADC Input Ranges.
 *
 * See datasheet section 8.5.2.3.3.
 */
typedef enum {
    ADS8698_RANGE_BIPOLAR_2_5X   = 0x00,  // 0 +/- 2.5 x Vref
    ADS8698_RANGE_BIPOLAR_1_25X  = 0x01,  // 0 +/- 1.25 x Vref
    ADS8698_RANGE_BIPOLAR_0_625X = 0x02,  // 0 +/- 0.625 x Vref
    ADS8698_RANGE_UNIPOLAR_2_5X  = 0x05,  // 0 + 2.5 x Vref
    ADS8698_RANGE_UNIPOLAR_1_25X = 0x0    // 0 + 1.25 x Vref
} ADS8698_range;


/* Initialize the ADC. */
void ADS8698_init(void);

/* Set the input range on the ADC. */
void ADS8698_set_range(ADS8698_range range);

/* Send a command to the ADC. */
void ADS8698_send_command(ADS8698_command command);

/* Reset the ADC. */
void ADS8698_reset(void);
